package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.PostCollections;
import com.ruoyi.system.domain.vo.PostCollectionsVo;

import java.util.List;

/**
 * 藏品Mapper接口
 *
 * @author ruoyi
 * @date 2023-02-15
 */
public interface PostCollectionsMapper
{
    /**
     * 查询藏品
     *
     * @param id 藏品主键
     * @return 藏品
     */
    public PostCollectionsVo selectPostCollectionsById(Long id);

    /**
     * 查询藏品列表
     *
     * @param id 藏品
     * @return 藏品集合
     */
    public List<PostCollections> selectPostCollectionsList(Long id);

    /**
     * 新增藏品
     *
     * @param postCollectionsVo 藏品
     * @return 结果
     */
    public int insertPostCollections(PostCollectionsVo postCollectionsVo);

    /**
     * 修改藏品
     *
     * @param postCollections 藏品
     * @return 结果
     */
    public int updatePostCollections(PostCollections postCollections);

    /**
     * 删除藏品
     *
     * @param id 藏品主键
     * @return 结果
     */
    public int deletePostCollectionsById(Long id);

    /**
     * 批量删除藏品
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePostCollectionsByIds(Long[] ids);
    /**
     * 根据藏品名称查询藏品数量
     *
     * @param postCollectionsVo 藏品
     * @return 结果
     */
    public int selectPostCollectionsByName(PostCollectionsVo postCollectionsVo);

    //批量修改藏品未上架时状态status
    Long updatePostCollectionsStatus(PostCollections postCollections);
    //批量更新上架时的状态
    public void updatePostCollectionsStatus1(PostCollections postCollections );

    void deletePostCollectionsBySystemIds(Long[] ids);
    //根据SystemId和id修改
    public void updatePostCollectionsBySysetmIdAndId(PostCollections postCollections);
}
